@@ -2,7 +2,7 @@ package Devel::Examine::Subs;
 use warnings;
 use strict;
 
-our $VERSION = '1.28';
+our $VERSION = '1.29';
 
 use Carp;
 use Data::Compare;
@@ -19,7 +19,6 @@ sub new {
 
     my $self = {};
     bless $self, shift;
-
     my $p = $self->_params(@_);
 
     # default configs
@@ -64,21 +63,22 @@ sub _run_directory {
     my $dir = $self->{params}{file};
 
     find({wanted => sub {
-                        return if ! -f;
+            return if ! -f;
 
-                        my @extensions = @{$self->{params}{extensions}};
-                        my $exts = join('|', @extensions);
+            my @extensions = @{$self->{params}{extensions}};
+            my $exts = join('|', @extensions);
 
-                        if ($_ !~ /\.(?:$exts)$/i){
-                            return;
-                        }
+            if ($_ !~ /\.(?:$exts)$/i){
+                return;
+            }
 
-                        my $file = "$File::Find::name";
+            my $file = "$File::Find::name";
 
-                        push @files, $file;
-                      },
-                        no_chdir => 1
-                    }, $dir );
+            push @files, $file;
+          },
+            no_chdir => 1
+        }, $dir
+    );
 
     my %struct;
 
@@ -96,6 +96,7 @@ sub _run_directory {
     return \%struct;
 }
 sub _run_end {
+
     my $self = shift;
     my $value = shift;
 
@@ -104,6 +105,7 @@ sub _run_end {
     return $self->{run_end};
 }
 sub _cache {
+
     my $self = shift;
     my $file = shift if @_;
     my $struct = shift if @_;
@@ -125,10 +127,12 @@ sub _cache {
     }
 }
 sub _cache_enabled {
+
     my $self = shift;
     return $self->{params}{cache};
 }
 sub _cache_safe {
+
     my $self = shift;
     my $value = shift;
 
@@ -137,12 +141,14 @@ sub _cache_safe {
     return $self->{cache_safe};
 }
 sub _params {
+
     my $self = shift;
     my %params = @_;
     return \%params;
 }
 sub _config {
 
+
     my $self = shift;
     my $p = shift;
 
@@ -185,6 +191,8 @@ sub _config {
         engine_return => 0,
         config_dump => 0,
         cache_dump => 0,
+        inject_use => 0,
+        delete => 0,
     );
 
     $self->{valid_params} = \%valid_params;
@@ -233,6 +241,7 @@ sub _config {
     }
 }
 sub _clean_config {
+
     my $self = shift;
     my $config_vars = shift; # href of valid params
     my $p = shift; # href of params passed in
@@ -258,6 +267,7 @@ sub _clean_config {
     }
 }
 sub _clean_core_config {
+
     # deletes core phase info after each run
 
     my $self = shift;
@@ -274,6 +284,7 @@ sub _clean_core_config {
 }
 sub _file {
 
+
     my $self = shift;
     my $p = shift;
 
@@ -421,17 +432,17 @@ sub _core {
     return $subs;
 }
 sub _subs {
-
+    
     my $self = shift;
     
     my $file = $self->{params}{file};
 
     return {} if ! $file;
-    
-    my $PPI_doc = PPI::Document->new($file);
-    my $PPI_subs = $PPI_doc->find("PPI::Statement::Sub");
 
-    return if ! $PPI_subs;
+    my $PPI_doc = PPI::Document->new($file);
+    my $PPIsubs = $PPI_doc->find("PPI::Statement::Sub");
+
+    return if ! $PPIsubs;
 
     tie my @TIE_file, 'Tie::File', $file;
 
@@ -440,7 +451,7 @@ sub _subs {
     
     @{$subs{$file}{TIE_file}} = @TIE_file;
 
-    for my $PPI_sub (@{$PPI_subs}){
+    for my $PPI_sub (@{$PPIsubs}){
 
         my $include = $self->{params}{include} // [];
         my $exclude = $self->{params}{exclude} // [];
@@ -794,6 +805,29 @@ sub search_replace {
 
     $self->run($p);
 }
+sub inject {
+    my $self = shift;
+    my $p = $self->_params(@_);
+
+    # inject_use is a preproc
+
+    if ($p->{inject_use}){
+        $self->{params}{pre_proc} = 'inject';
+        $self->{params}{pre_proc_return} = 1;
+    }
+
+    $self->run($p);
+}
+sub remove {
+
+    my $self = shift;
+    my $p = $self->_params(@_);
+
+    $self->{params}{pre_proc} = 'remove';
+    $self->{params}{pre_proc_return} = 1;
+
+    $self->run($p);
+}
 sub inject_after {
 
     my $self = shift;
@@ -875,6 +909,7 @@ sub add_functionality {
     push @TIE_file, @code;
 }
 sub valid_params {
+
     my $self = shift;
     return %{$self->{valid_params}};
 }
@@ -1127,6 +1162,28 @@ with '.bak', but don't confuse this feature with the 'copy' parameter.
 
 
 
+=head2 C<inject>
+
+Parameters: C<inject_use =E<gt> ['use Module::Name', 'use Module2::Name']>
+
+The only current option is this parameter. It will inject the statements prior
+to all existing C<use> statements that already exist in the file(s). If none
+are found, will inject the statements right after a C<Package> statement if
+found.
+
+Technically, you don't have to inject a C<use> statement, but I'd advise it.
+
+
+
+=head2 C<remove>
+
+Parameters: C<delete =E<gt> ['string1', 'string2']>
+
+Deletes from the file(s) the entire lines that contain the search terms.
+
+This method is file based... the work happens prior to digging up subs, hence
+C<exclude>, C<include> and other sub-based parameters have no effect.
+
 
 
 =head2 C<inject_after>
