@@ -10,7 +10,7 @@ use Devel::Examine::Subs::Sub;
 use File::Copy;
 use Tie::File;
 
-our $VERSION = '1.28';
+our $VERSION = '1.29';
 
 sub new {
 
@@ -43,6 +43,7 @@ sub _dt {
     return $dt;
 }
 sub exists {
+
     my $self = shift;
     my $string = shift;
 
@@ -323,9 +324,10 @@ sub inject_after {
  
         copy $file, "$file.bak";
 
-        unlink $copy if -f $copy;
-        
         if ($copy){
+            if (-f $copy){
+                unlink $copy;
+            }
             copy $file, $copy;
             $file = $copy;
         }
@@ -379,7 +381,7 @@ sub inject_after {
                        
                         my $location = $line_num;
 
-                        my $indent;
+                        my $indent = '';
 
                         if (! $p->{no_indent}){
                             if ($line =~ /^(\s+)/ && $1){
@@ -412,6 +414,7 @@ sub inject_after {
     };                        
 }
 1;
+
 sub _vim_placeholder {}
 
 __END__
@@ -427,8 +430,10 @@ Devel::Examine::Subs
 
     my $compiler = Devel::Examine::Subs::Engine->new;
 
+    my $engine = 'has';
+
     if (! $compiler->exists($engine)){
-        croak "engine '$engine' is not implemented.\n";
+        croak "engine $engine is not implemented.\n";
     }
 
     eval {
