@@ -1,11 +1,12 @@
 package Devel::Examine::Subs::Preprocessor;
 
-use strict; use warnings;
+use strict; 
+use warnings;
 
 use Carp;
 use Data::Dumper;
 
-our $VERSION = '1.28';
+our $VERSION = '1.29';
 
 sub new {
 
@@ -25,6 +26,8 @@ sub _dt {
 
     my $dt = {
         module => \&module,
+        inject => \&inject,
+        remove => \&remove,
         _test_bad => \&test_bad,
     };
 
@@ -73,13 +76,71 @@ sub module {
         return \@subs;
     };
 }
+
+sub inject {
+
+    return sub {
+
+        my $p = shift;
+        my $file = $p->{file};
+
+        if ($p->{inject_use}) {
+            
+            tie my @file, 'Tie::File', $file or die $!;
+
+            my $use = qr/use\s+\w+/;
+
+            my ($index) = grep { $file[$_] =~ $use } 0..$#file;
+
+            if (! $index) {
+                ($index) = grep { $file[$_] =~ /^package\s+\w+/ } 0..$#file;
+            }
+
+            if ($index) {
+                for (@{$p->{inject_use}}) {
+                    splice @file, $index, 0, $_;
+                }
+            }
+
+            untie @file;
+
+            return;
+        }
+    }
+}
+
+sub remove {
+
+    return sub {
+        
+        my $p = shift;
+        my $file = $p->{file};        
+        my $delete = $p->{delete};
+
+        tie my @file, 'Tie::File', $file or die $!; 
+    
+        for my $find (@$delete){
+            while (my ($index) = grep { $file[$_] =~ $find } 0..$#file){
+                splice @file, $index, 1;
+            }
+        }
+        untie @file;
+
+        return;
+    }
+}
+
 1;
+
+
 sub _vim_placeholder {}
+
 __END__
 
 =head1 NAME
 
-Devel::Examine::Subs::Preprocessor - Provides core pre_proc callbacks for Devel::Examine::Subs
+Devel::Examine::Subs::Preprocessor - Provides core pre_proc callbacks for
+Devel::Examine::Subs
 
 =head1 SYNOPSIS
 
@@ -99,26 +160,32 @@ Devel::Examine::Subs::Preprocessor - Provides core pre_proc callbacks for Devel:
 
 =head1 DESCRIPTION
 
-Pre-processors run prior to the main processing routine that does the file reading and subroutine compilations.
+Pre-processors run prior to the main processing routine that does the file
+reading and subroutine compilations.
 
-Use a pre-processor to manipulate the system early in the call chain, or get and return data that doesn't require reading any files.
+Use a pre-processor to manipulate the system early in the call chain, or get
+and return data that doesn't require reading any files.
 
-Use C<Devel::Examine::Subs> C<pre_proc_return> parameter to return the data after the pre-processor has run to avoid unnecessary work by the processor.
+Use C<Devel::Examine::Subs> C<pre_proc_return> parameter to return the data
+after the pre-processor has run to avoid unnecessary work by the processor.
 
 =head1 METHODS
 
-All methods other than C<exists()> takes an href of configuration data as it's first parameter.
+All methods other than C<exists()> takes an href of configuration data as its
+first parameter.
 
 =head2 C<exists('pre_proc')>
 
-Verifies whether the engine name specified as the string parameter exists and is valid.
+Verifies whether the engine name specified as the string parameter exists and
+is valid.
 
 
 =head2 C<module>
 
 Mandatory parameters: C<{ module => 'Module::Name' }>
 
-This pre-processor returns an array reference of all subroutines within the namespace of the module listed in the C<module> parameter.
+This pre-processor returns an array reference of all subroutines within the
+namespace of the module listed in the C<module> parameter.
 
 The data is returned early as mentioned in the L<DESCRIPTION>.
 
@@ -136,8 +203,9 @@ You can find documentation for this module with the perldoc command.
 
 Copyright 2015 Steve Bertrand.
 
-This program is free software; you can redistribute it and/or modify it under the terms of either: the GNU General Public License as 
-published by the Free Software Foundation; or the Artistic License.
+This program is free software; you can redistribute it and/or modify it under
+the terms of either: the GNU General Public License as published by the Free
+Software Foundation; or the Artistic License.
 
 See http://dev.perl.org/licenses/ for more information.
 
